<?php
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_FILES['csvFile'])) {
    $file = $_FILES['csvFile']['tmp_name'];

    // Open the uploaded CSV file
    if (($handle = fopen($file, "r")) !== FALSE) {
        // Assuming the file is in UTF-8 encoding
        setlocale(LC_ALL, 'en_US.UTF-8');

        // Use semicolon as a delimiter
        $header = fgetcsv($handle, 0, ';'); // Get the header row using semicolon delimiter
        $structuredData = [];

        // Define mappings for AlternArtikelNr1 (with special characters)
        // $mapping = [
        //     'Tischform: Eckig / Breite: 95 cm / Länge: 208.5 cm / Kanten: 45° Kante' => 'DTE45-950X2085',
        //     'Tischform: Rund | Durchmesser: 100 cm | Kanten: 45° Kante' => 'DTE45-1000R',
        //     'Tischform: Eckig / Breite: 90 cm / Länge: 160 cm / Kanten: 90° Kante' => 'DTE90-900X1600',
        //     'Tischform: Rund | Durchmesser: 110 cm | Kanten: 90° Kante' => 'DTE90-1100R',
        // ];


        // Dynamic mapping logic based on patterns in Tischform, Breite/Länge, Durchmesser, and Kanten
        function generateMapping($attribute) {
            $mapping = '';

            // Check if Tischform is Eckig (square/rectangular)
            if (strpos($attribute, 'Tischform: Eckig') !== false) {
                // Find Breite and Länge for Eckig tables
                if (preg_match('/Breite: (\d+(\.\d+)?) cm/', $attribute, $breiteMatch) &&
                    preg_match('/Länge: (\d+(\.\d+)?) cm/', $attribute, $langeMatch)) {
                    $breite = $breiteMatch[1];
                    $lange = $langeMatch[1];

                    // Check Kanten (edges) for Eckig tables
                    if (strpos($attribute, 'Kanten: 45° Kante') !== false) {
                        $mapping = 'DTE45-' . $breite . 'X' . $lange;
                    } elseif (strpos($attribute, 'Kanten: 90° Kante') !== false) {
                        $mapping = 'DTE90-' . $breite . 'X' . $lange;
                    }
                }
            }
            // Check if Tischform is Rund (round)
            elseif (strpos($attribute, 'Tischform: Rund') !== false) {
                // Find Durchmesser for Rund tables
                if (preg_match('/Durchmesser: (\d+(\.\d+)?) cm/', $attribute, $durchmesserMatch)) {
                    $durchmesser = $durchmesserMatch[1];

                    // Check Kanten (edges) for Rund tables
                    if (strpos($attribute, 'Kanten: 45° Kante') !== false) {
                        $mapping = 'DTE45-' . $durchmesser . 'R';
                    } elseif (strpos($attribute, 'Kanten: 90° Kante') !== false) {
                        $mapping = 'DTE90-' . $durchmesser . 'R';
                    }
                }
            }

            return $mapping;
        }
        
        // Process CSV rows
        while (($data = fgetcsv($handle, 0, ';')) !== FALSE) {
            // Ensure all rows have the same number of columns as the header
            if (count($data) != count($header)) {
                $data = array_pad($data, count($header), ''); // Pad with empty strings for missing values
            }

            $row = array_combine($header, $data);

            // Normalize encoding and handle special characters
            $attribute = $row['Attribute'];

            // Convert the attribute to UTF-8 to avoid encoding mismatches
            $attribute = iconv('ISO-8859-1', 'UTF-8//IGNORE', $attribute);
            $attribute = trim($attribute); // Ensure no extra spaces or hidden characters

            // Debugging - to ensure the exact content of $attribute
            // var_dump($attribute);

            // Extract necessary fields and transform
            $structuredRow = [
                'Artikelbeschreibung' => isset($row['Artikelbeschreibung']) ? $row['Artikelbeschreibung'] : '', // Default blank if value is missing
                'LFirma' => isset($row['LFirma']) ? $row['LFirma'] : '',
                'Lvorname' => isset($row['Lvorname']) ? $row['Lvorname'] : '',
                'Lnachname' => isset($row['Lnachname']) ? $row['Lnachname'] : '',
                'Lstrasse' => isset($row['Lstrasse']) ? $row['Lstrasse'] : '',
                'Lplz' => isset($row['Lplz']) ? $row['Lplz'] : '',
                'Lort' => isset($row['Lort']) ? $row['Lort'] : '',
                'LLand' => isset($row['LLand']) ? $row['LLand'] : '',
                'ReNr' => isset($row['ReNr']) ? $row['ReNr'] : '',
                'Menge' => isset($row['Menge']) ? $row['Menge'] : '',
                'Telefon' => isset($row['Telefon']) ? $row['Telefon'] : '',

                // Use normalized 'Attribute' field for comparison and check the mapping
                'AlternArtikelNr1' => generateMapping($attribute)
            ];

            $structuredData[] = $structuredRow;
        }
        fclose($handle);

        // Prepare the CSV for download
        $outputFilename = 'structured_data.csv';
        header('Content-Type: text/csv; charset=UTF-8');
        header('Content-Disposition: attachment; filename=' . $outputFilename);
        $output = fopen('php://output', 'w');

        // Write CSV headers
        fputcsv($output, array_keys($structuredData[0]), ';'); // Output with semicolon delimiter

        // Write CSV rows
        foreach ($structuredData as $structuredRow) {
            fputcsv($output, $structuredRow, ';');
        }
        fclose($output);
        exit;
    } else {
        echo "Error opening the file.";
    }
}
?>
